[![HitCount](http://hits.dwyl.io/debdutgoswami/instagram-profile-picture.svg)](http://hits.dwyl.io/debdutgoswami/instagram-profile-picture)

# Instagram Profile Picture Extraction

I have used python to open and also download Instagram profile pictures as because Instagram does not allow us to open the picture.

## installation

Hosted on _pypi.org_

```
pip install ig-profile
```

## example

```
from ig_profile import ProfileImage as pimage
pimage.image(YOUR_USER_NAME)
```

The above code will simply download the desired profile picture and open it up in a new window.


## PyPi

Instagram Profile Picture: [PyPi](https://pypi.org/project/ig-profile/)
